==> google_cloud_life_sciences-0.4.1-py2.py3-none-any.whl: google/cloud/lifesciences_v2beta/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.workflows_service_v2_beta import WorkflowsServiceV2BetaClient
from .services.workflows_service_v2_beta import WorkflowsServiceV2BetaAsyncClient

from .types.workflows import Accelerator
from .types.workflows import Action
from .types.workflows import ContainerKilledEvent
from .types.workflows import ContainerStartedEvent
from .types.workflows import ContainerStoppedEvent
from .types.workflows import DelayedEvent
from .types.workflows import Disk
from .types.workflows import Event
from .types.workflows import ExistingDisk
from .types.workflows import FailedEvent
from .types.workflows import Metadata
from .types.workflows import Mount
from .types.workflows import Network
from .types.workflows import NFSMount
from .types.workflows import PersistentDisk
from .types.workflows import Pipeline
from .types.workflows import PullStartedEvent
from .types.workflows import PullStoppedEvent
from .types.workflows import Resources
from .types.workflows import RunPipelineRequest
from .types.workflows import RunPipelineResponse
from .types.workflows import Secret
from .types.workflows import ServiceAccount
from .types.workflows import UnexpectedExitStatusEvent
from .types.workflows import VirtualMachine
from .types.workflows import Volume
from .types.workflows import WorkerAssignedEvent
from .types.workflows import WorkerReleasedEvent

__all__ = (
    "WorkflowsServiceV2BetaAsyncClient",
    "Accelerator",
    "Action",
    "ContainerKilledEvent",
    "ContainerStartedEvent",
    "ContainerStoppedEvent",
    "DelayedEvent",
    "Disk",
    "Event",
    "ExistingDisk",
    "FailedEvent",
    "Metadata",
    "Mount",
    "NFSMount",
    "Network",
    "PersistentDisk",
    "Pipeline",
    "PullStartedEvent",
    "PullStoppedEvent",
    "Resources",
    "RunPipelineRequest",
    "RunPipelineResponse",
    "Secret",
    "ServiceAccount",
    "UnexpectedExitStatusEvent",
    "VirtualMachine",
    "Volume",
    "WorkerAssignedEvent",
    "WorkerReleasedEvent",
    "WorkflowsServiceV2BetaClient",
)

==> google_cloud_life_sciences-0.7.1-py2.py3-none-any.whl: google/cloud/lifesciences_v2beta/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.workflows_service_v2_beta import (
    WorkflowsServiceV2BetaAsyncClient,
    WorkflowsServiceV2BetaClient,
)
from .types.workflows import (
    Accelerator,
    Action,
    ContainerKilledEvent,
    ContainerStartedEvent,
    ContainerStoppedEvent,
    DelayedEvent,
    Disk,
    Event,
    ExistingDisk,
    FailedEvent,
    Metadata,
    Mount,
    Network,
    NFSMount,
    PersistentDisk,
    Pipeline,
    PullStartedEvent,
    PullStoppedEvent,
    Resources,
    RunPipelineRequest,
    RunPipelineResponse,
    Secret,
    ServiceAccount,
    UnexpectedExitStatusEvent,
    VirtualMachine,
    Volume,
    WorkerAssignedEvent,
    WorkerReleasedEvent,
)

__all__ = (
    "WorkflowsServiceV2BetaAsyncClient",
    "Accelerator",
    "Action",
    "ContainerKilledEvent",
    "ContainerStartedEvent",
    "ContainerStoppedEvent",
    "DelayedEvent",
    "Disk",
    "Event",
    "ExistingDisk",
    "FailedEvent",
    "Metadata",
    "Mount",
    "NFSMount",
    "Network",
    "PersistentDisk",
    "Pipeline",
    "PullStartedEvent",
    "PullStoppedEvent",
    "Resources",
    "RunPipelineRequest",
    "RunPipelineResponse",
    "Secret",
    "ServiceAccount",
    "UnexpectedExitStatusEvent",
    "VirtualMachine",
    "Volume",
    "WorkerAssignedEvent",
    "WorkerReleasedEvent",
    "WorkflowsServiceV2BetaClient",
)
